#
# spec file for package libqt5-qtvirtualkeyboard
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define qt5_snapshot 1

Name:           libqt5-qtvirtualkeyboard
Version:        5.15.16+kde0
Release:        1.1
Summary:        Qt 5 Virtual Keyboard
License:        GPL-3.0
Group:          Development/Libraries/X11
Url:            https://www.qt.io
%define base_name libqt5
%define real_version 5.15.16
%define so_version 5.15.16
%define tar_version qtvirtualkeyboard-everywhere-src-%{version}
Source:         %{tar_version}.tar.xz
BuildRequires:  libQt5Gui-private-headers-devel >= %{real_version}
BuildRequires:  libQt5Core-private-headers-devel >= %{real_version}
BuildRequires:  pkgconfig(Qt5Qml) >= %{real_version}
BuildRequires:  pkgconfig(Qt5Quick) >= %{real_version}
BuildRequires:  pkgconfig(Qt5Svg) >= %{real_version}
%if %qt5_snapshot
#to create the forwarding headers
BuildRequires:  perl
%endif
BuildRequires:  xz
BuildRequires:  pkgconfig(xcb)
BuildRequires:  pkgconfig(hunspell)
# Was part of the core before 5.12
Recommends:     %{name}-hunspell
%requires_ge libQtQuick5

%description
Qt is a set of libraries for developing applications.

This package contains a virtual keyboard.

%package -n libQt5VirtualKeyboard5
Summary:       Qt5 Virtual Keyboard library
Group:         System/Libraries

%description -n libQt5VirtualKeyboard5
Internal library used by Qt for providing Hunspell support.

%package examples
Summary:        Qt5 virtualkeyboard examples
Group:          Development/Libraries/X11

%description examples
Examples for libqt5-qtvirtualkeyboard module.

%package devel
Summary:        Qt Development Kit
Group:          Development/Libraries/X11
Requires:       %{name} = %{version}

%description devel
You need this package if you want to compile programs or plugins with
Qt Virtual Keyboard.

%package private-headers-devel
Summary:        Non-ABI stable API for the Qt5 Virtual Keyboard
Group:          Development/Libraries/C and C++
Requires:       %{name}-devel = %{version}
Requires:       libQt5Gui-private-headers-devel >= %{real_version}
Requires:       libQt5Core-private-headers-devel >= %{real_version}

%description private-headers-devel
This package provides private headers of libqt5-qtvirtualkeyboard that are
normally not used by application development and that do not have any ABI or
API guarantees. The packages that build against these have to require
the exact Qt version.

%package hunspell
Summary:       Hunspell Plugin for the Qt5 Virtual Keyboard
# TODO!
Group:         System/Libraries
Requires:      %{name} = %{version}

%description hunspell
This package provides a hunspell spell checking plugin for the Qt Virtual Keyboard.

%package -n libQt5HunspellInputMethod5
Summary:       Qt5 Hunspell Input Method
Group:         System/Libraries

%description -n libQt5HunspellInputMethod5
Internal library used by Qt for providing Hunspell support.

%package -n libQt5HunspellInputMethod-private-headers-devel
Summary:        Non-ABI stable API for libQt5HunspellInputMethod
Group:          Development/Libraries/C and C++
Requires:       libQt5HunspellInputMethod5 = %{version}	
Requires:       %{name}-private-headers-devel = %{version}

%description -n libQt5HunspellInputMethod-private-headers-devel
This package provides private headers of libQt5HunspellInputMethod that are
normally not used by application development and that do not have any ABI or
API guarantees. The packages that build against these have to require
the exact Qt version.

%prep
%autosetup -p1 -n %{tar_version}

%build
%if %qt5_snapshot
#force the configure script to generate the forwarding headers (it checks whether .git directory exists)
mkdir .git
%endif
# Only enable languages that don't force-include bundled 3rdparty libs
%qmake5 "CONFIG+=lang-ar_AR lang-da_DK lang-de_DE lang-en_GB lang-es_ES lang-fa_FA lang-fi_FI lang-fr_FR lang-hi_IN lang-it_IT lang-nb_NO lang-pl_PL lang-pt_PT lang-ro_RO lang-ru_RU lang-sv_SE"
%make_jobs

%install
%qmake5_install

# kill .la files
rm -f %{buildroot}%{_libqt5_libdir}/lib*.la

%post   -n libQt5VirtualKeyboard5 -p /sbin/ldconfig
%postun -n libQt5VirtualKeyboard5 -p /sbin/ldconfig
%post   -n libQt5HunspellInputMethod5 -p /sbin/ldconfig
%postun -n libQt5HunspellInputMethod5 -p /sbin/ldconfig

%files
%license LICENSE.*
%dir %{_libqt5_plugindir}/virtualkeyboard
%{_libqt5_plugindir}/platforminputcontexts/libqtvirtualkeyboardplugin.so
%{_libqt5_archdatadir}/qml/QtQuick/VirtualKeyboard/

%files -n libQt5VirtualKeyboard5
%license LICENSE.*
%{_libqt5_libdir}/libQt5VirtualKeyboard.so.*

%files devel
%license LICENSE.*
%exclude %{_libqt5_includedir}/QtVirtualKeyboard/%{so_version}
%{_libqt5_includedir}/QtVirtualKeyboard/
%{_libqt5_libdir}/cmake/Qt5VirtualKeyboard/
%{_libqt5_libdir}/cmake/Qt5Gui/Qt5Gui_QVirtualKeyboardPlugin.cmake
%{_libqt5_libdir}/libQt5VirtualKeyboard.prl
%{_libqt5_libdir}/libQt5VirtualKeyboard.so
%{_libqt5_libdir}/pkgconfig/Qt5VirtualKeyboard.pc
%{_libqt5_libdir}/qt5/mkspecs/modules/qt_lib_virtualkeyboard.pri

%files private-headers-devel
%license LICENSE.*
%{_libqt5_libdir}/qt5/mkspecs/modules/qt_lib_virtualkeyboard_private.pri
%{_libqt5_includedir}/QtVirtualKeyboard/%{so_version}/

%files hunspell
%license LICENSE.*
%{_libqt5_plugindir}/virtualkeyboard/libqtvirtualkeyboard_hunspell.so

%files -n libQt5HunspellInputMethod5
%license LICENSE.*
%{_libqt5_libdir}/libQt5HunspellInputMethod.so.*

%files -n libQt5HunspellInputMethod-private-headers-devel
%license LICENSE.*
# Private headers + non-private Version/Depends headers
%{_libqt5_includedir}/QtHunspellInputMethod/
%{_libqt5_libdir}/libQt5HunspellInputMethod.prl
%{_libqt5_libdir}/libQt5HunspellInputMethod.so
%{_libqt5_libdir}/cmake/Qt5HunspellInputMethod/
%{_libqt5_libdir}/qt5/mkspecs/modules/qt_lib_hunspellinputmethod_private.pri

%files examples
%license LICENSE.*
%{_libqt5_examplesdir}/

%changelog
* Mon Nov 25 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to version 5.15.16+kde0, rebased upstream:
  * Fix repeated style loading
  * Bump version to 5.15.16
* Wed Sep  4 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to version 5.15.15+kde0, rebased upstream:
  * Bump version to 5.15.15
* Wed May 29 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to version 5.15.14+kde0, rebased upstream:
  * Bump version to 5.15.14
* Tue Mar 19 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to version 5.15.13+kde0, rebased upstream:
  * Disable shadow input cursor blinking while invisible
  * Bump version to 5.15.13
* Fri Dec 29 2023 Fabian Vogt <fabian@ritter-vogt.de>
- Update to version 5.15.12+kde0, rebased upstream:
  * Doc: Improve locale section of technical guide
  * Fix visible area in the basic example
  * Bump version to 5.15.12
* Fri Oct  6 2023 Fabian Vogt <fabian@ritter-vogt.de>
- Update to version 5.15.11+kde0, rebased upstream:
  * Remove platform-dependent codes for XCB
* Tue Jun 13 2023 Fabian Vogt <fabian@ritter-vogt.de>
- Update to version 5.15.10+kde0, rebased upstream:
  * No code changes
* Fri Apr 21 2023 Fabian Vogt <fabian@ritter-vogt.de>
- Update to version 5.15.8+kde6, rebased upstream:
  * Fix activation of input panel when initial active focus is set
  * Blacklist: test cases blacklisted in inputpanel:
  * Blacklist more test_fullScreenModeSelectionHandles rows
  * Disable Windows IME when Qt Virtual Keyboard plugin is loaded
* Mon Jan  9 2023 Fabian Vogt <fabian@ritter-vogt.de>
- Update to version 5.15.8+kde0, rebased upstream:
  * Doc: Mention plugin dependencies in the deployment guide
  * Blacklist more flaky tests on QEMU.
  * Blacklist tst_plugin::test_fullScreenModeWordReselection
  * Blacklist certain tests that check selection handle positions
  * Only reparent the InputPanel when necessary
  * Document the reparenting of InputPanel during modal sessions
* Thu Nov  3 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to version 5.15.7+kde0, rebased upstream:
  * No code changes
* Mon Sep 26 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to version 5.15.6+kde1, rebased upstream:
  * Doc: Add readonly command to VirtualKeyboardSettings::availableLocales
  * pinyin: Do not accept invalid input as pinyin initial
  * pinyin: Prevent crash when pinyin dictionary cannot be loaded
  * plugins/openwnn: reset() should not modify pre-edit text
  * plugins/openwnn: Set word candidate index when item is selected
* Mon Jun 27 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to version 5.15.5+kde3, rebased upstream:
  * Revert "Update commercial license headers"
  * Pinyin: not mix upper and lower case
  * Fix position of the keyboardRectangle in app integration
  * Update commercial license headers
- Drop 0001-Revert-Bump-version.patch, it's versioned correctly now
* Fri Jan 21 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to version 5.15.2+kde6:
  * Fix processing of hard Qt::Key_Backspace and Qt::Key_Delete
  * Fix high CPU utilization caused by key repeat timer
* Thu Oct 28 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to version 5.15.2+kde4:
  * Avoid reparenting of InputPanel when the window is being destroyed
* Tue Jun 22 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Switch to KDE's maintenance branch
- Update to version 5.15.2+kde3:
  * Suggest phrases based on the last selected word of pinyin
  * Add changes file for Qt 5.15.2
  * Bump version
- Add patch to reset version to 5.15.2:
  * 0001-Revert-Bump-version.patch
* Fri Nov 20 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.15.2:
  * New bugfix release
  * For more details please see:
    http://code.qt.io/cgit/qt/qtvirtualkeyboard.git/plain/dist/changes-5.15.2/?h=5.15.2
* Thu Sep 10 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.15.1:
  * New bugfix release
  * For more details please see:
    http://code.qt.io/cgit/qt/qtvirtualkeyboard.git/plain/dist/changes-5.15.1/?h=5.15.1
* Tue May 26 2020 Callum Farmer <callumjfarmer13@gmail.com>
- Update to version 5.15.0:
  * No changelog available
* Wed May 20 2020 Callum Farmer <callumjfarmer13@gmail.com>
- Update to version 5.15.0-rc2:
  * No changelog available
* Wed May  6 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.15.0-rc:
  * New bugfix release
  * For the changes between 5.14.2 and 5.15.0 please see:
    http://code.qt.io/cgit/qt/qtvirtualkeyboard.git/plain/dist/changes-5.15.0/?h=5.15.0
* Fri Apr 24 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.15.0-beta4:
  * New bugfix release
  * No changelog available
* Tue Apr 14 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.15.0-beta3:
  * New bugfix release
  * No changelog available
* Tue Mar 24 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.15.0-beta2:
  * New bugfix release
  * No changelog available
* Fri Feb 28 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.15.0-beta1:
  * New bugfix release
  * No changelog available
* Wed Feb 19 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.15.0-alpha:
  * New feature release
  * For more details please see:
    https://wiki.qt.io/New_Features_in_Qt_5.15
* Mon Jan 27 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.14.1:
  * New bugfix release
  * For more details please see:
    http://code.qt.io/cgit/qt/qtvirtualkeyboard.git/plain/dist/changes-5.14.1/?h=v5.14.1
* Thu Dec 12 2019 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.14.0:
  * New bugfix release
  * For the changes between 5.13.2 and 5.14.0 please see:
    https://code.qt.io/cgit/qt/qtvirtualkeyboard.git/tree/dist/changes-5.14.0?h=v5.14.0
  * For the changes between 5.13.1 and 5.13.2 please see:
    https://code.qt.io/cgit/qt/qtvirtualkeyboard.git/tree/dist/changes-5.13.2?h=v5.14.0
* Wed Dec  4 2019 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.14.0-rc:
  * New bugfix release
  * No changelog available
  * For more details please see:
  * For more details about Qt 5.14 please see:
    https://wiki.qt.io/New_Features_in_Qt_5.14
* Tue Nov 12 2019 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.14.0-beta3:
  * New bugfix release
  * No changelog available
* Thu Oct 24 2019 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.14.0-beta2:
  * New bugfix release
  * No changelog available
* Tue Oct 15 2019 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.14.0-beta1:
  * New bugfix release
  * No changelog available
* Mon Sep 30 2019 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.14.0-alpha:
  * New feature release
  * No changelog available
  * For more details about Qt 5.14 please see:
    https://wiki.qt.io/New_Features_in_Qt_5.14
* Fri Sep  6 2019 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.13.1:
  * New bugfix release
  * For more details please see:
  * http://code.qt.io/cgit/qt/qtvirtualkeyboard.git/plain/dist/changes-5.13.1/?h=v5.13.1
* Wed Jun 19 2019 fabian@ritter-vogt.de
- Update to 5.13.0:
  * New bugfix release
  * No changelog available
  * For more details about Qt 5.13 please see:
  * http://code.qt.io/cgit/qt/qtvirtualkeyboard.git/plain/dist/changes-5.13.0/?h=5.13
* Tue Jun  4 2019 fabian@ritter-vogt.de
- Update to 5.13.0-rc:
  * New bugfix release
  * No changelog available
* Mon Apr 29 2019 fabian@ritter-vogt.de
- Update to 5.13.0-beta2:
  * New bugfix release
  * No changelog available
* Thu Apr 18 2019 fabian@ritter-vogt.de
- Update to 5.12.3:
  * New bugfix release
  * For more details please see:
  * http://code.qt.io/cgit/qt/qtvirtualkeyboard.git/plain/dist/changes-5.12.3/?h=v5.12.3
* Thu Mar 21 2019 fabian@ritter-vogt.de
- Update to 5.13.0-beta1:
  * New feature release
  * For more details about Qt 5.13 please see:
  * http://code.qt.io/cgit/qt/qtvirtualkeyboard.git/plain/dist/changes-5.13.0/?h=5.13
* Thu Mar 14 2019 fabian@ritter-vogt.de
- Update to 5.12.2:
  * New bugfix release
  * For more details please see:
  * http://code.qt.io/cgit/qt/qtvirtualkeyboard.git/plain/dist/changes-5.12.2/?h=5.12.2
* Fri Feb  1 2019 fabian@ritter-vogt.de
- Update to 5.12.1:
  * New bugfix release
  * For more details please see:
  * http://code.qt.io/cgit/qt/qtvirtualkeyboard.git/plain/dist/changes-5.12.1/?h=v5.12.1
* Thu Dec 20 2018 Christophe Giboudeaux <christophe@krop.fr>
- Fix the libQt5HunspellInputMethod-private-headers-devel requirements.
* Thu Dec  6 2018 fabian@ritter-vogt.de
- Update to 5.12.0:
  * New feature release
  * For more details please see:
  * http://code.qt.io/cgit/qt/qtvirtualkeyboard.git/plain/dist/changes-5.12.0/?h=v5.12.0
* Mon Dec  3 2018 fabian@ritter-vogt.de
- Update to 5.12.0-rc2:
  * New bugfix release
  * Only important bugfixes
- Changelog for Qt 5.12.0:
  * http://code.qt.io/cgit/qt/qtvirtualkeyboard.git/plain/dist/changes-5.12.0/?h=5.12.0
* Thu Nov 22 2018 fabian@ritter-vogt.de
- Update to 5.12.0-rc:
  * New bugfix release
  * No changelog available
* Thu Nov  8 2018 fabian@ritter-vogt.de
- Update to 5.12.0-beta4:
  * New bugfix release
  * No changelog available
* Fri Oct 26 2018 fabian@ritter-vogt.de
- Update to 5.12.0-beta3:
  * New bugfix release
  * No changelog available
* Wed Oct 17 2018 fabian@ritter-vogt.de
- Update to 5.12.0-beta2:
  * New bugfix release
  * No changelog available
* Fri Oct  5 2018 fabian@ritter-vogt.de
- Update to 5.12.0-beta1:
  * New bugfix release
  * No changelog available
* Tue Oct  2 2018 fabian@ritter-vogt.de
- Update to 5.12.0-alpha:
  * New feature release
  * For more details please see:
  * http://wiki.qt.io/New_Features_in_Qt_5.12
  * Extension API added
  * hunspell support split into a (private) library and plugin
* Fri Sep 21 2018 fabian@ritter-vogt.de
- Update to 5.11.2
  * New bugfix release
  * For more details please see:
  * http://code.qt.io/cgit/qt/qtvirtualkeyboard.git/plain/dist/changes-5.11.2/?h=v5.11.2
* Tue Jun 19 2018 fabian@ritter-vogt.de
- Update to 5.11.1
  * New bugfix release
  * For more details please see:
  * http://code.qt.io/cgit/qt/qtvirtualkeyboard.git/plain/dist/changes-5.11.1/?h=v5.11.1
* Tue May 22 2018 fabian@ritter-vogt.de
- Update to 5.11.0
  * New bugfix release
  * For more details please see:
  * http://code.qt.io/cgit/qt/qtvirtualkeyboard.git/plain/dist/changes-5.11.0/?h=v5.11.0
* Tue May  8 2018 fabian@ritter-vogt.de
- Update to 5.11.0-rc
  * New bugfix release
  * No changelog available
* Mon Apr 23 2018 fabian@ritter-vogt.de
- Update to 5.11.0-beta4
  * New bugfix release
  * No changelog available
* Wed Apr 11 2018 fabian@ritter-vogt.de
- Update to 5.11.0-beta3
  * New bugfix release
  * No changelog available
* Wed Mar 28 2018 fabian@ritter-vogt.de
- Update to 5.11.0-beta2
  * New bugfix release
  * No changelog available
* Thu Mar  1 2018 fabian@ritter-vogt.de
- Update to 5.11.0-beta1
  * New feature release
  * For more details please see:
  * http://code.qt.io/cgit/qt/qtvirtualkeyboard.git/plain/dist/changes-5.11.0-beta1/?h=v5.11.0-beta1
* Tue Feb 20 2018 fabian@ritter-vogt.de
- Update to 5.11.0-alpha
  * New feature release
  * For more details please see:
  * https://wiki.qt.io/New_Features_in_Qt_5.11
* Wed Feb 14 2018 fabian@ritter-vogt.de
- Update to 5.10.1
  * New bugfix release
  * For more details please see:
  * http://code.qt.io/cgit/qt/qtvirtualkeyboard.git/plain/dist/changes-5.10.1/?h=v5.10.1
* Thu Dec  7 2017 fabian@ritter-vogt.de
- Update to 5.10.0 final
  * New bugfix release
* Sun Dec  3 2017 fabian@ritter-vogt.de
- Update to 5.10.0 RC 2
  * New bugfix release
* Thu Nov 30 2017 fabian@ritter-vogt.de
- Update to 5.10.0 RC 1
  * New bugfix release
* Sat Nov 25 2017 fabian@ritter-vogt.de
- Update to 5.9.3
  * New bugfix release
  * For more details, see:
    http://code.qt.io/cgit/qt/qtvirtualkeyboard.git/tree/dist/changes-5.9.3/?h=v5.9.3
* Wed Nov 15 2017 fabian@ritter-vogt.de
- Update to 5.10 Beta 4
- Contains bugfixes
* Thu Nov  2 2017 fabian@ritter-vogt.de
- Update to 5.10 Beta 3
- Contains bugfixes
* Mon Oct 30 2017 fabian@ritter-vogt.de
- Update to 5.10 Beta 2
- Contains bugfixes
* Mon Oct  9 2017 fabian@ritter-vogt.de
- Update to 5.10 Beta 1
- For more information visit:
    https://blog.qt.io/blog/2017/10/09/qt-5-10-beta-released/
* Sun Oct  8 2017 lbeltrame@kde.org
- Update to 5.9.2
  * For more details please see:
    https://blog.qt.io/blog/2017/10/06/qt-5-9-2-released/
* Mon Sep 25 2017 fabian@ritter-vogt.de
- Update to 5.10 Alpha 1:
  * Added the following keyboard layouts: Hebrew, Serbian, Hungarian, Czech, Croatian, Bulgarian, Greek, Estonian, and Dutch.
  * Added handwriting support for Farsi, Arabic, and CJK (Chinese/Japanese/Korean).
  * Added new component (InputModeKey) for input mode switch.
  * OpenWNN:
    + Fixed crash when pressing the space after entering a smiley.
    + Fixed and optimized OpenWNN engine
- For more information visit:
    https://blog.qt.io/blog/2017/09/13/qt-5-10-alpha-released/
* Sat Jul  1 2017 lbeltrame@kde.org
- Update to 5.9.1
  * For more details please see:
    http://blog.qt.io/blog/2017/06/30/qt-5-9-1-released/
* Wed May 31 2017 fabian@ritter-vogt.de
- Update to 5.9.0 final
* Wed May 24 2017 fabian@ritter-vogt.de
- Update to 5.9.0 RC:
  * For more details please see:
    http://lists.qt-project.org/pipermail/announce/2017-May/000115.html
    and https://wiki.qt.io/New_Features_in_Qt_5.9
* Mon Mar 20 2017 fabian@ritter-vogt.de
- Downgrade to 5.7.1 for factory submission
* Fri Feb 24 2017 fabian@ritter-vogt.de
- Add initial package, based on libqt5-qtgraphicaleffects
